"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var util_1 = require("../util");
var storage_1 = require("../storage");
var definition_1 = require("../definition");
var DefaultStorage = /** @class */ (function () {
    /**
     * @stable [28.07.2019]
     * @param {string} prefix
     * @param {() => ISettings} settingsProvider
     * @param {StorageTypeEnum} storageType
     */
    function DefaultStorage(prefix, settingsProvider, storageType) {
        this.prefix = prefix;
        this.settingsProvider = settingsProvider;
        this.storageType = storageType;
    }
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @param {AnyT} value
     * @returns {Promise<boolean>}
     */
    DefaultStorage.prototype.set = function (key, value) {
        this.storage.setItem(this.toKey(key), JSON.stringify(value));
        return Promise.resolve(true);
    };
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @returns {Promise<AnyT>}
     */
    DefaultStorage.prototype.get = function (key) {
        return Promise.resolve(util_1.ifNotNilThanValue(this.storage.getItem(this.toKey(key)), function (v) { return JSON.parse(v); }));
    };
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @param {boolean} noPrefix
     * @returns {Promise<boolean>}
     */
    DefaultStorage.prototype.remove = function (key, noPrefix) {
        this.storage.removeItem(noPrefix ? key : this.toKey(key));
        return Promise.resolve(true);
    };
    /**
     * @stable [28.07.2019]
     * @param {(key: string, value: AnyT) => void} callback
     */
    DefaultStorage.prototype.each = function (callback) {
        var storage = this.storage;
        for (var i = 0; i < storage.length; i++) {
            var key = storage.key(i);
            callback(this.toKey(key), storage.getItem(key));
        }
    };
    Object.defineProperty(DefaultStorage.prototype, "storage", {
        /**
         * @stable [28.07.2019]
         * @returns {Storage}
         */
        get: function () {
            var settings = this.settingsProvider();
            switch (util_1.nvl(this.storageType, settings && settings.persistenceStorage)) {
                case definition_1.StorageTypeEnum.SESSION:
                    return sessionStorage;
                default:
                    return localStorage;
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [28.07.2019]
     * @param {string} key
     * @returns {string}
     */
    DefaultStorage.prototype.toKey = function (key) {
        return [this.prefix, key].join(storage_1.STORAGE_KEY_SEPARATOR);
    };
    return DefaultStorage;
}());
exports.DefaultStorage = DefaultStorage;
//# sourceMappingURL=storage.service.js.map